Welcome to ClientVPS Mirrors

Help for package shopifyadsR
Type: Package
Title: Get 'Shopify' Ads Data via the 'Windsor.ai' API
Version: 0.1.0
Description: Collect your data on digital marketing campaigns from 'Shopify' Ads using the 'Windsor.ai' API https://windsor.ai/api-fields/.
License: GPL-3
URL: https://windsor.ai/
Depends: R (≥ 3.5.0)
Imports: jsonlite (≥ 1.7.2)
Suggests: knitr, rmarkdown, dplyr, ggplot2, tidyr, curl
VignetteBuilder: knitr
Encoding: UTF-8
Language: en-US
LazyData: true
RoxygenNote: 7.2.1
NeedsCompilation: no
Packaged: 2022-11-01 15:30:50 UTC; pablo
Author: Pablo Sanchez [cre, aut], Windsor.ai [cph]
Maintainer: Pablo Sanchez <pablosama@outlook.es>
Repository: CRAN
Date/Publication: 2022-11-02 14:42:52 UTC

fetch_shopifyads A function to fetch Shopify Ads data from the windsor.ai API

Description

fetch_shopifyads A function to fetch Shopify Ads data from the windsor.ai API

Usage

fetch_shopifyads(
  api_key,
  date_from = NULL,
  date_to = NULL,
  fields = c("campaign", "clicks", "spend", "impressions", "date")
)

Arguments

api_key

Your api key to access Windsor.ai API

date_from

The date from which to start getting data in format YYYY-MM-DD

date_to

The date until which to start getting data in format YYYY-MM-DD

fields

he fields fetched from the API for a given connector See https://windsor.ai/api-fields/ for details.

Value

A data frame with the desired data

Examples

## Not run: 
my_shopifyads_data <- fetch_shopifyads(api_key = "your api key",
date_from = "2022-10-01",
date_to = "2022-10-02",
fields = c("campaign", "clicks",
"spend", "impressions", "date"))

## End(Not run)

Sample of digital marketing data from Shopify Ads downloaded by means of the Windsor.ai API.

Description

A dataset containing sample Shopify ads data fetched from windsor.ai API. See more at: https://windsor.ai/

Usage

my_shopifyads_data

Format

A data frame with 164 rows and 5 variables:

campaign

name of the campaign

clicks

number of clicks

spend

spend data

impressions

impressions data

date

date

https://windsor.ai/

Need a high-speed mirror for your open-source project?
Contact our mirror admin team at info@clientvps.com.

This archive is provided as a free public service to the community.
Proudly supported by infrastructure from VPSPulse , RxServers , BuyNumber , UnitVPS , OffshoreName and secure payment technology by ArionPay.